from django_notify.tests.cookie import CookieTest
from django_notify.tests.fallback import FallbackTest
from django_notify.tests.middleware import MiddlewareTest
from django_notify.tests.session import SessionTest
from django_notify.tests.user_messages import UserMessagesTest, \
    LegacyFallbackTest
